==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/S3SnapshotAsset.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__doubleMin0
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class S3SnapshotAsset(size: __doubleMin0) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset = {
    import S3SnapshotAsset.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
      .builder()
      .size(__doubleMin0.unwrap(size): java.lang.Double)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.S3SnapshotAsset.ReadOnly =
    zio.aws.dataexchange.model.S3SnapshotAsset.wrap(buildAwsValue())
}
object S3SnapshotAsset {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.S3SnapshotAsset =
      zio.aws.dataexchange.model.S3SnapshotAsset(size)
    def size: __doubleMin0
    def getSize: ZIO[Any, Nothing, __doubleMin0] = ZIO.succeed(size)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
  ) extends zio.aws.dataexchange.model.S3SnapshotAsset.ReadOnly {
    override val size: __doubleMin0 =
      zio.aws.dataexchange.model.primitives.__doubleMin0(impl.size())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
  ): zio.aws.dataexchange.model.S3SnapshotAsset.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-6.20.115.2-sources.jar: zio/aws/dataexchange/model/S3SnapshotAsset.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__doubleMin0
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class S3SnapshotAsset(size: __doubleMin0) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset = {
    import S3SnapshotAsset.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
      .builder()
      .size(size: java.lang.Double)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.S3SnapshotAsset.ReadOnly =
    zio.aws.dataexchange.model.S3SnapshotAsset.wrap(buildAwsValue())
}
object S3SnapshotAsset {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.S3SnapshotAsset =
      zio.aws.dataexchange.model.S3SnapshotAsset(size)
    def size: __doubleMin0
    def getSize: ZIO[Any, Nothing, __doubleMin0] = ZIO.succeed(size)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
  ) extends zio.aws.dataexchange.model.S3SnapshotAsset.ReadOnly {
    override val size: __doubleMin0 = impl.size(): __doubleMin0
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.S3SnapshotAsset
  ): zio.aws.dataexchange.model.S3SnapshotAsset.ReadOnly = new Wrapper(impl)
}
